summaryrefslogtreecommitdiffstats
path: root/kpdf
diff options
context:
space:
mode:
Diffstat (limited to 'kpdf')
-rw-r--r--kpdf/conf/dlgperformance.ui2
-rw-r--r--kpdf/core/document.cpp14
-rw-r--r--kpdf/core/generator_pdf/generator_pdf.cpp12
-rw-r--r--kpdf/core/link.cpp4
-rw-r--r--kpdf/core/page.cpp2
-rw-r--r--kpdf/core/page.h2
-rw-r--r--kpdf/core/pagetransition.cpp2
-rw-r--r--kpdf/core/pagetransition.h6
-rw-r--r--kpdf/error.cpp2
-rw-r--r--kpdf/part.cpp12
-rw-r--r--kpdf/ui/pagepainter.cpp4
-rw-r--r--kpdf/ui/pageview.cpp84
-rw-r--r--kpdf/ui/pageviewutils.cpp38
-rw-r--r--kpdf/ui/pageviewutils.h6
-rw-r--r--kpdf/ui/presentationwidget.cpp70
-rw-r--r--kpdf/ui/presentationwidget.h2
-rw-r--r--kpdf/ui/propertiesdialog.cpp4
-rw-r--r--kpdf/ui/thumbnaillist.cpp4
18 files changed, 135 insertions, 135 deletions
diff --git a/kpdf/conf/dlgperformance.ui b/kpdf/conf/dlgperformance.ui
index b495e05f..994e05ff 100644
--- a/kpdf/conf/dlgperformance.ui
+++ b/kpdf/conf/dlgperformance.ui
@@ -138,7 +138,7 @@
<property name="textFormat">
<enum>PlainText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
diff --git a/kpdf/core/document.cpp b/kpdf/core/document.cpp
index 84566364..c3c24a3d 100644
--- a/kpdf/core/document.cpp
+++ b/kpdf/core/document.cpp
@@ -118,7 +118,7 @@ KPDFDocument::KPDFDocument(TQWidget *widget)
TQStringList::Iterator it = list.begin();
while( it != list.end() )
{
- d->kimgioMimes << KMimeType::findByPath(TQString("foo.%1").tqarg(*it), 0, true)->name();
+ d->kimgioMimes << KMimeType::findByPath(TQString("foo.%1").arg(*it), 0, true)->name();
++it;
}
}
@@ -331,7 +331,7 @@ void KPDFDocument::reparseConfig()
// reparse generator config and if something changed clear KPDFPages
if ( generator && generator->reparseConfig() )
{
- // tqinvalidate pixmaps
+ // invalidate pixmaps
TQValueVector<KPDFPage*>::iterator it = pages_vector.begin(), end = pages_vector.end();
for ( ; it != end; ++it )
(*it)->deletePixmapsAndRects();
@@ -712,7 +712,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
- // reset cursor to previous tqshape
+ // reset cursor to previous shape
TQApplication::restoreOverrideCursor();
// send page lists if found anything new
@@ -764,7 +764,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
- // reset cursor to previous tqshape
+ // reset cursor to previous shape
TQApplication::restoreOverrideCursor();
// if a match has been found..
@@ -793,7 +793,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
else if ( !noDialogs )
- KMessageBox::information( widget(), i18n("No matches found for '%1'.").tqarg( text ) );
+ KMessageBox::information( widget(), i18n("No matches found for '%1'.").arg( text ) );
}
// 3. PREVMATCH //TODO
else if ( type == PrevMatch )
@@ -865,7 +865,7 @@ bool KPDFDocument::searchText( int searchID, const TQString & text, bool fromSta
}
}
- // reset cursor to previous tqshape
+ // reset cursor to previous shape
TQApplication::restoreOverrideCursor();
// send page lists to update observers (since some filter on bookmarks)
@@ -1016,7 +1016,7 @@ void KPDFDocument::processLink( const KPDFLink * link )
KRun::run( *ptr, lst );
}
else
- KMessageBox::information( widget(), i18n( "No application found for opening file of mimetype %1." ).tqarg( mime->name() ) );
+ KMessageBox::information( widget(), i18n( "No application found for opening file of mimetype %1." ).arg( mime->name() ) );
} break;
case KPDFLink::Action: {
diff --git a/kpdf/core/generator_pdf/generator_pdf.cpp b/kpdf/core/generator_pdf/generator_pdf.cpp
index 0133e010..02ce1148 100644
--- a/kpdf/core/generator_pdf/generator_pdf.cpp
+++ b/kpdf/core/generator_pdf/generator_pdf.cpp
@@ -209,7 +209,7 @@ const DocumentInfo * PDFGenerator::generateDocumentInfo()
if ( pdfdoc )
{
docInfo.set( "format", i18n( "PDF v. <version>", "PDF v. %1" )
- .tqarg( TQString::number( pdfdoc->getPDFVersion() ) ), i18n( "Format" ) );
+ .arg( TQString::number( pdfdoc->getPDFVersion() ) ), i18n( "Format" ) );
docInfo.set( "encryption", pdfdoc->isEncrypted() ? i18n( "Encrypted" ) : i18n( "Unencrypted" ),
i18n("Security") );
docInfo.set( "optimization", pdfdoc->isLinearized() ? i18n( "Yes" ) : i18n( "No" ),
@@ -528,7 +528,7 @@ static GString *TQStringToGString(const TQString &s) {
int len = s.length();
char *cstring = (char *)gmallocn(s.length(), sizeof(char));
for (int i = 0; i < len; ++i)
- cstring[i] = s.tqat(i).tqunicode();
+ cstring[i] = s.at(i).tqunicode();
return new GString(cstring, len);
}
@@ -909,11 +909,11 @@ void PDFGenerator::addSynopsisChildren( TQDomNode * parent, GList * items )
item.setAttribute( "Open", TQVariant( (bool)outlineItem->isOpen() ).toString() );
- // 3. recursively descend over tqchildren
+ // 3. recursively descend over children
outlineItem->open();
- GList * tqchildren = outlineItem->getKids();
- if ( tqchildren )
- addSynopsisChildren( &item, tqchildren );
+ GList * children = outlineItem->getKids();
+ if ( children )
+ addSynopsisChildren( &item, children );
}
}
diff --git a/kpdf/core/link.cpp b/kpdf/core/link.cpp
index a872ba60..fd4aa141 100644
--- a/kpdf/core/link.cpp
+++ b/kpdf/core/link.cpp
@@ -18,12 +18,12 @@ KPDFLink::~KPDFLink()
TQString KPDFLinkGoto::linkTip() const
{
- return m_extFileName.isEmpty() ? ( m_vp.pageNumber != -1 ? i18n( "Go to page %1" ).tqarg( m_vp.pageNumber + 1 ) : TQString() ) : i18n("Open external file");
+ return m_extFileName.isEmpty() ? ( m_vp.pageNumber != -1 ? i18n( "Go to page %1" ).arg( m_vp.pageNumber + 1 ) : TQString() ) : i18n("Open external file");
}
TQString KPDFLinkExecute::linkTip() const
{
- return i18n( "Execute '%1'..." ).tqarg( m_fileName );
+ return i18n( "Execute '%1'..." ).arg( m_fileName );
}
TQString KPDFLinkBrowse::linkTip() const
diff --git a/kpdf/core/page.cpp b/kpdf/core/page.cpp
index 269cab2e..0014d26a 100644
--- a/kpdf/core/page.cpp
+++ b/kpdf/core/page.cpp
@@ -319,7 +319,7 @@ bool NormalizedRect::intersects( double l, double t, double r, double b ) const
return (l < right) && (r > left) && (t < bottom) && (b > top);
}
-TQRect NormalizedRect::tqgeometry( int xScale, int yScale ) const
+TQRect NormalizedRect::geometry( int xScale, int yScale ) const
{
int l = (int)( left * xScale ),
t = (int)( top * yScale ),
diff --git a/kpdf/core/page.h b/kpdf/core/page.h
index 1ec5add0..2de7aceb 100644
--- a/kpdf/core/page.h
+++ b/kpdf/core/page.h
@@ -36,7 +36,7 @@ class NormalizedRect
bool intersects( const NormalizedRect & normRect ) const;
bool intersects( double l, double t, double r, double b ) const;
- TQRect tqgeometry( int xScale, int yScale ) const;
+ TQRect geometry( int xScale, int yScale ) const;
};
/**
diff --git a/kpdf/core/pagetransition.cpp b/kpdf/core/pagetransition.cpp
index 41d743c6..c43da45a 100644
--- a/kpdf/core/pagetransition.cpp
+++ b/kpdf/core/pagetransition.cpp
@@ -15,7 +15,7 @@
KPDFPageTransition::KPDFPageTransition( Type type )
: m_type( type ),
m_duration( 1 ),
- m_tqalignment(Horizontal ),
+ m_alignment(Horizontal ),
m_direction( Inward ),
m_angle( 0 ),
m_scale( 1.0 ),
diff --git a/kpdf/core/pagetransition.h b/kpdf/core/pagetransition.h
index bc2740ab..70792355 100644
--- a/kpdf/core/pagetransition.h
+++ b/kpdf/core/pagetransition.h
@@ -51,7 +51,7 @@ class KPDFPageTransition
inline int duration() const { return m_duration; }
// Get dimension in which the transition effect occurs.
- inline Alignment tqalignment() const { return m_tqalignment; }
+ inline Alignment alignment() const { return m_alignment; }
// Get direction of motion of the transition effect.
inline Direction direction() const { return m_direction; }
@@ -67,7 +67,7 @@ class KPDFPageTransition
inline void setType( Type type ) { m_type = type; }
inline void setDuration( int duration ) { m_duration = duration; }
- inline void setAlignment( Alignment tqalignment ) { m_tqalignment = tqalignment; }
+ inline void setAlignment( Alignment alignment ) { m_alignment = alignment; }
inline void setDirection( Direction direction ) { m_direction = direction; }
inline void setAngle( int angle ) { m_angle = angle; }
inline void setScale( double scale ) { m_scale = scale; }
@@ -76,7 +76,7 @@ class KPDFPageTransition
private:
Type m_type;
int m_duration;
- Alignment m_tqalignment;
+ Alignment m_alignment;
Direction m_direction;
int m_angle;
double m_scale;
diff --git a/kpdf/error.cpp b/kpdf/error.cpp
index ca62437f..00d3581e 100644
--- a/kpdf/error.cpp
+++ b/kpdf/error.cpp
@@ -32,7 +32,7 @@ void CDECL error(int pos, char *msg, ...) {
return;
}
if (pos >= 0) {
- emsg = TQString("Error (%1): ").tqarg(pos);
+ emsg = TQString("Error (%1): ").arg(pos);
} else {
emsg = "Error: ";
}
diff --git a/kpdf/part.cpp b/kpdf/part.cpp
index 1e222000..2638e718 100644
--- a/kpdf/part.cpp
+++ b/kpdf/part.cpp
@@ -297,7 +297,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
m_showPresentation = new KAction( i18n("P&resentation"), "kpresenter_kpr", "Ctrl+Shift+P", this, TQT_SLOT(slotShowPresentation()), ac, "presentation");
m_showPresentation->setEnabled( false );
- // attach the actions of the tqchildren widgets too
+ // attach the actions of the children widgets too
m_pageView->setupActions( ac );
// apply configuration (both internal settings and GUI configured items)
@@ -510,7 +510,7 @@ bool Part::openURL(const KURL &url)
// these setWindowCaption calls only work for local files
if ( !b )
{
- KMessageBox::error( widget(), i18n("Could not open %1").tqarg( url.prettyURL() ) );
+ KMessageBox::error( widget(), i18n("Could not open %1").arg( url.prettyURL() ) );
emit setWindowCaption("");
}
else
@@ -806,17 +806,17 @@ void Part::slotSaveFileAs()
{
if (saveURL == url())
{
- KMessageBox::information( widget(), i18n("You are trying to overwrite \"%1\" with itself. This is not allowed. Please save it in another location.").tqarg(saveURL.filename()) );
+ KMessageBox::information( widget(), i18n("You are trying to overwrite \"%1\" with itself. This is not allowed. Please save it in another location.").arg(saveURL.filename()) );
return;
}
if ( KIO::NetAccess::exists( saveURL, false, widget() ) )
{
- if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").tqarg(saveURL.filename()), TQString(), i18n("Overwrite")) != KMessageBox::Continue)
+ if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(saveURL.filename()), TQString(), i18n("Overwrite")) != KMessageBox::Continue)
return;
}
if ( !KIO::NetAccess::file_copy( m_file, saveURL, -1, true ) )
- KMessageBox::information( 0, i18n("File could not be saved in '%1'. Try to save it to another location.").tqarg( saveURL.prettyURL() ) );
+ KMessageBox::information( 0, i18n("File could not be saved in '%1'. Try to save it to another location.").arg( saveURL.prettyURL() ) );
}
}
@@ -939,7 +939,7 @@ void Part::slotShowMenu(const KPDFPage *page, const TQPoint &point)
KPopupMenu *popup = new KPopupMenu( widget(), "rmb popup" );
if (page)
{
- popup->insertTitle( i18n( "Page %1" ).tqarg( page->number() + 1 ) );
+ popup->insertTitle( i18n( "Page %1" ).arg( page->number() + 1 ) );
if ( page->hasBookmark() )
popup->insertItem( SmallIcon("bookmark"), i18n("Remove Bookmark"), 1 );
else
diff --git a/kpdf/ui/pagepainter.cpp b/kpdf/ui/pagepainter.cpp
index 27a9626e..f5b659b5 100644
--- a/kpdf/ui/pagepainter.cpp
+++ b/kpdf/ui/pagepainter.cpp
@@ -178,7 +178,7 @@ void PagePainter::paintPageOnPainter( const KPDFPage * page, int id, int flags,
for ( ; hIt != hEnd; ++hIt )
{
HighlightRect * r = *hIt;
- TQRect highlightRect = r->tqgeometry( width, height );
+ TQRect highlightRect = r->geometry( width, height );
if ( highlightRect.isValid() && highlightRect.intersects( limits ) )
{
// find out the rect to highlight on pixmap
@@ -226,7 +226,7 @@ void PagePainter::paintPageOnPainter( const KPDFPage * page, int id, int flags,
if ( (enhanceLinks && rect->objectType() == ObjectRect::Link) ||
(enhanceImages && rect->objectType() == ObjectRect::Image) )
{
- TQRect rectGeometry = rect->tqgeometry( width, height );
+ TQRect rectGeometry = rect->geometry( width, height );
if ( rectGeometry.intersects( limitsEnlarged ) )
{
// expand rect and draw inner border
diff --git a/kpdf/ui/presentationwidget.cpp b/kpdf/ui/presentationwidget.cpp
index 4e8373ca..12ebe96d 100644
--- a/kpdf/ui/presentationwidget.cpp
+++ b/kpdf/ui/presentationwidget.cpp
@@ -43,12 +43,12 @@
#define ENABLE_PROGRESS_OVERLAY
-// a frame contains a pointer to the page object, its tqgeometry and the
+// a frame contains a pointer to the page object, its geometry and the
// transition effect to the next frame
struct PresentationFrame
{
const KPDFPage * page;
- TQRect tqgeometry;
+ TQRect geometry;
};
@@ -56,7 +56,7 @@ PresentationWidget::PresentationWidget( TQWidget * parent, KPDFDocument * doc )
: TQDialog( parent, "presentationWidget", true, WDestructiveClose | WStyle_NoBorder),
m_pressedLink( 0 ), m_handCursor( false ), m_document( doc ), m_frameIndex( -1 )
{
- // set look and tqgeometry
+ // set look and geometry
setBackgroundMode( TQt::NoBackground );
m_width = -1;
@@ -124,7 +124,7 @@ void PresentationWidget::notifySetup( const TQValueVector< KPDFPage * > & pageSe
{
PresentationFrame * frame = new PresentationFrame();
frame->page = *setIt;
- // calculate frame tqgeometry keeping constant aspect ratio
+ // calculate frame geometry keeping constant aspect ratio
float pageRatio = frame->page->ratio();
int pageWidth = m_width,
pageHeight = m_height;
@@ -132,7 +132,7 @@ void PresentationWidget::notifySetup( const TQValueVector< KPDFPage * > & pageSe
pageWidth = (int)( (float)pageHeight / pageRatio );
else
pageHeight = (int)( (float)pageWidth * pageRatio );
- frame->tqgeometry.setRect( (m_width - pageWidth) / 2,
+ frame->geometry.setRect( (m_width - pageWidth) / 2,
(m_height - pageHeight) / 2,
pageWidth, pageHeight );
// add the frame to the vector
@@ -145,11 +145,11 @@ void PresentationWidget::notifySetup( const TQValueVector< KPDFPage * > & pageSe
if ( info )
{
if ( !info->get( "title" ).isNull() )
- m_metaStrings += i18n( "Title: %1" ).tqarg( info->get( "title" ) );
+ m_metaStrings += i18n( "Title: %1" ).arg( info->get( "title" ) );
if ( !info->get( "author" ).isNull() )
- m_metaStrings += i18n( "Author: %1" ).tqarg( info->get( "author" ) );
+ m_metaStrings += i18n( "Author: %1" ).arg( info->get( "author" ) );
}
- m_metaStrings += i18n( "Pages: %1" ).tqarg( m_document->pages() );
+ m_metaStrings += i18n( "Pages: %1" ).arg( m_document->pages() );
m_metaStrings += i18n( "Click to begin" );
}
@@ -287,9 +287,9 @@ void PresentationWidget::mouseMoveEvent( TQMouseEvent * e )
else
{
// show the bar if reaching top 2 pixels
- if ( e->y() <= (tqgeometry().top() + 1) )
+ if ( e->y() <= (geometry().top() + 1) )
m_topBar->show();
- // handle "dragging the wheel" if clicking on its tqgeometry
+ // handle "dragging the wheel" if clicking on its geometry
else if ( e->state() == Qt::LeftButton && m_overlayGeometry.contains( e->pos() ) )
overlayClick( e->pos() );
}
@@ -330,12 +330,12 @@ void PresentationWidget::paintEvent( TQPaintEvent * pe )
}
// check painting rect consistancy
- TQRect r = pe->rect().intersect( tqgeometry() );
+ TQRect r = pe->rect().intersect( geometry() );
if ( r.isNull() || m_lastRenderedPixmap.isNull() )
return;
// blit the pixmap to the screen
- TQMemArray<TQRect> allRects = TQRegion(pe->region()).tqrects();
+ TQMemArray<TQRect> allRects = TQRegion(pe->region()).rects();
uint numRects = allRects.count();
for ( uint i = 0; i < numRects; i++ )
{
@@ -370,18 +370,18 @@ void PresentationWidget::paintEvent( TQPaintEvent * pe )
// </widget events>
-const KPDFLink * PresentationWidget::getLink( int x, int y, TQRect * tqgeometry ) const
+const KPDFLink * PresentationWidget::getLink( int x, int y, TQRect * geometry ) const
{
// no links on invalid pages
- if ( tqgeometry && !tqgeometry->isNull() )
- tqgeometry->setRect( 0, 0, -1, -1 );
+ if ( geometry && !geometry->isNull() )
+ geometry->setRect( 0, 0, -1, -1 );
if ( m_frameIndex < 0 || m_frameIndex >= (int)m_frames.size() )
return 0;
- // get frame, page and tqgeometry
+ // get frame, page and geometry
const PresentationFrame * frame = m_frames[ m_frameIndex ];
const KPDFPage * page = frame->page;
- const TQRect & frameGeometry = frame->tqgeometry;
+ const TQRect & frameGeometry = frame->geometry;
// compute normalized x and y
double nx = (double)(x - frameGeometry.left()) / (double)frameGeometry.width();
@@ -396,11 +396,11 @@ const KPDFLink * PresentationWidget::getLink( int x, int y, TQRect * tqgeometry
if ( !object )
return 0;
- // compute link tqgeometry if destination rect present
- if ( tqgeometry )
+ // compute link geometry if destination rect present
+ if ( geometry )
{
- *tqgeometry = object->tqgeometry( frameGeometry.width(), frameGeometry.height() );
- tqgeometry->moveBy( frameGeometry.left(), frameGeometry.top() );
+ *geometry = object->geometry( frameGeometry.width(), frameGeometry.height() );
+ geometry->moveBy( frameGeometry.left(), frameGeometry.top() );
}
// return the link pointer
@@ -416,7 +416,7 @@ void PresentationWidget::testCursorOnLink( int x, int y )
// only react on changes (in/out from a link)
if ( (link && !m_handCursor) || (!link && m_handCursor) )
{
- // change cursor tqshape
+ // change cursor shape
m_handCursor = link != 0;
setCursor( m_handCursor ? KCursor::handCursor() : KCursor::arrowCursor());
@@ -451,8 +451,8 @@ void PresentationWidget::changePage( int newPage )
// check if pixmap exists or else request it
m_frameIndex = newPage;
PresentationFrame * frame = m_frames[ m_frameIndex ];
- int pixW = frame->tqgeometry.width();
- int pixH = frame->tqgeometry.height();
+ int pixW = frame->geometry.width();
+ int pixH = frame->geometry.height();
// if pixmap not inside the KPDFPage we request it and wait for
// notifyPixmapChanged call or else we can proceed to pixmap generation
@@ -470,16 +470,16 @@ void PresentationWidget::changePage( int newPage )
if (newPage + 1 < (int)m_document->pages())
{
PresentationFrame *nextFrame = m_frames[ newPage + 1 ];
- pixW = nextFrame->tqgeometry.width();
- pixH = nextFrame->tqgeometry.height();
+ pixW = nextFrame->geometry.width();
+ pixH = nextFrame->geometry.height();
if ( !nextFrame->page->hasPixmap( PRESENTATION_ID, pixW, pixH ) )
requests.push_back( new PixmapRequest( PRESENTATION_ID, newPage + 1, pixW, pixH, PRESENTATION_PRELOAD_PRIO, true ) );
}
if (newPage - 1 >= 0)
{
PresentationFrame *prevFrame = m_frames[ newPage - 1 ];
- pixW = prevFrame->tqgeometry.width();
- pixH = prevFrame->tqgeometry.height();
+ pixW = prevFrame->geometry.width();
+ pixH = prevFrame->geometry.height();
if ( !prevFrame->page->hasPixmap( PRESENTATION_ID, pixW, pixH ) )
requests.push_back( new PixmapRequest( PRESENTATION_ID, newPage - 1, pixW, pixH, PRESENTATION_PRELOAD_PRIO, true ) );
}
@@ -595,7 +595,7 @@ void PresentationWidget::generateContentsPage( int pageNum, TQPainter & p )
PresentationFrame * frame = m_frames[ pageNum ];
// translate painter and contents rect
- TQRect geom( frame->tqgeometry );
+ TQRect geom( frame->geometry );
p.translate( geom.left(), geom.top() );
geom.moveBy( -geom.left(), -geom.top() );
@@ -605,11 +605,11 @@ void PresentationWidget::generateContentsPage( int pageNum, TQPainter & p )
&p, geom, geom.width(), geom.height() );
// restore painter
- p.translate( -frame->tqgeometry.left(), -frame->tqgeometry.top() );
+ p.translate( -frame->geometry.left(), -frame->geometry.top() );
// fill unpainted areas with background color
TQRegion unpainted( TQRect( 0, 0, m_width, m_height ) );
- TQMemArray<TQRect> rects = TQRegion(unpainted.subtract( frame->tqgeometry )).tqrects();
+ TQMemArray<TQRect> rects = TQRegion(unpainted.subtract( frame->geometry )).rects();
for ( uint i = 0; i < rects.count(); i++ )
{
const TQRect & r = rects[i];
@@ -622,7 +622,7 @@ inline int qt_div255(int x) { return (x + (x>>8) + 0x80) >> 8; }
void PresentationWidget::generateOverlay()
{
#ifdef ENABLE_PROGRESS_OVERLAY
- // calculate overlay tqgeometry and resize pixmap if needed
+ // calculate overlay geometry and resize pixmap if needed
int side = m_width / 16;
m_overlayGeometry.setRect( m_width - side - 4, 4, side, side );
if ( m_lastRenderedOverlay.width() != side )
@@ -725,7 +725,7 @@ void PresentationWidget::generateOverlay()
m_lastRenderedOverlay.convertFromImage( image );
// start the autohide timer
- tqrepaint( m_overlayGeometry, false /*clear*/ ); // toggle with next line
+ repaint( m_overlayGeometry, false /*clear*/ ); // toggle with next line
//update( m_overlayGeometry );
m_overlayHideTimer->start( 2500, true );
#endif
@@ -963,7 +963,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
/** ONLY the TRANSITIONS GENERATION function from here on **/
void PresentationWidget::initTransition( const KPDFPageTransition *transition )
{
- // if it's just a 'replace' transition, tqrepaint the screen
+ // if it's just a 'replace' transition, repaint the screen
if ( transition->type() == KPDFPageTransition::Replace )
{
update();
@@ -971,7 +971,7 @@ void PresentationWidget::initTransition( const KPDFPageTransition *transition )
}
const bool isInward = transition->direction() == KPDFPageTransition::Inward;
- const bool isHorizontal = transition->tqalignment() == KPDFPageTransition::Horizontal;
+ const bool isHorizontal = transition->alignment() == KPDFPageTransition::Horizontal;
const float totalTime = transition->duration();
m_transitionRects.clear();
diff --git a/kpdf/ui/presentationwidget.h b/kpdf/ui/presentationwidget.h
index 26db0836..000bfeaa 100644
--- a/kpdf/ui/presentationwidget.h
+++ b/kpdf/ui/presentationwidget.h
@@ -60,7 +60,7 @@ class PresentationWidget : public TQDialog, public DocumentObserver
void paintEvent( TQPaintEvent * e );
private:
- const KPDFLink * getLink( int x, int y, TQRect * tqgeometry = 0 ) const;
+ const KPDFLink * getLink( int x, int y, TQRect * geometry = 0 ) const;
void testCursorOnLink( int x, int y );
void overlayClick( const TQPoint & position );
void changePage( int newPage );
diff --git a/kpdf/ui/propertiesdialog.cpp b/kpdf/ui/propertiesdialog.cpp
index d49f28be..06521692 100644
--- a/kpdf/ui/propertiesdialog.cpp
+++ b/kpdf/ui/propertiesdialog.cpp
@@ -35,7 +35,7 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
// mime name based on mimetype id
TQString mimeName = info->get( "mimeType" ).section( '/', -1 ).upper();
- setCaption( i18n("%1 Properties").tqarg( mimeName ) );
+ setCaption( i18n("%1 Properties").arg( mimeName ) );
TQDomElement docElement = info->documentElement();
@@ -50,7 +50,7 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
continue;
// create labels and tqlayout them
- TQLabel *key = new TQLabel( i18n( "%1:" ).tqarg( titleString ), page );
+ TQLabel *key = new TQLabel( i18n( "%1:" ).arg( titleString ), page );
TQLabel *value = new KSqueezedTextLabel( valueString, page );
tqlayout->addWidget( key, row, 0, AlignRight );
tqlayout->addWidget( value, row, 1 );
diff --git a/kpdf/ui/thumbnaillist.cpp b/kpdf/ui/thumbnaillist.cpp
index a41869d6..8f9359b5 100644
--- a/kpdf/ui/thumbnaillist.cpp
+++ b/kpdf/ui/thumbnaillist.cpp
@@ -199,7 +199,7 @@ void ThumbnailList::notifyPageChanged( int pageNumber, int /*changedFlags*/ )
//if ( !(changedFlags & DocumentObserver::Pixmap) )
// return;
- // iterate over visible items: if page(pageNumber) is one of them, tqrepaint it
+ // iterate over visible items: if page(pageNumber) is one of them, repaint it
TQValueList<ThumbnailWidget *>::iterator vIt = m_visibleThumbnails.begin(), vEnd = m_visibleThumbnails.end();
for ( ; vIt != vEnd; ++vIt )
if ( (*vIt)->pageNumber() == pageNumber )
@@ -362,7 +362,7 @@ void ThumbnailList::viewportResizeEvent( TQResizeEvent * e )
else if ( e->size().height() <= e->oldSize().height() )
return;
- // tqinvalidate the bookmark overlay
+ // invalidate the bookmark overlay
if ( m_bookmarkOverlay )
{
delete m_bookmarkOverlay;
diff --git a/kpdf/ui/pageview.cpp b/kpdf/ui/pageview.cpp
index b44b320c..b0b9da30 100644
--- a/kpdf/ui/pageview.cpp
+++ b/kpdf/ui/pageview.cpp
@@ -146,8 +146,8 @@ void PageViewTip::maybeTip( const TQPoint &_p )
PageViewItem * pageItem = m_view->pickItemOnPoint( p.x(), p.y() );
if ( pageItem && m_view->d->mouseMode == PageView::MouseNormal )
{
- double nX = (double)(p.x() - pageItem->tqgeometry().left()) / (double)pageItem->width(),
- nY = (double)(p.y() - pageItem->tqgeometry().top()) / (double)pageItem->height();
+ double nX = (double)(p.x() - pageItem->geometry().left()) / (double)pageItem->width(),
+ nY = (double)(p.y() - pageItem->geometry().top()) / (double)pageItem->height();
// if over a ObjectRect (of type Link) change cursor to hand
const ObjectRect * object = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
@@ -158,8 +158,8 @@ void PageViewTip::maybeTip( const TQPoint &_p )
TQString strtip = link->linkTip();
if ( !strtip.isEmpty() )
{
- TQRect linkRect = object->tqgeometry( pageItem->width(), pageItem->height() );
- linkRect.moveBy( - m_view->contentsX() + pageItem->tqgeometry().left(), - m_view->contentsY() + pageItem->tqgeometry().top() );
+ TQRect linkRect = object->geometry( pageItem->width(), pageItem->height() );
+ linkRect.moveBy( - m_view->contentsX() + pageItem->geometry().left(), - m_view->contentsY() + pageItem->geometry().top() );
tip( linkRect, strtip );
}
}
@@ -337,7 +337,7 @@ void PageView::notifySetup( const TQValueVector< KPDFPage * > & pageSet, bool do
d->items.clear();
d->visibleItems.clear();
- // create tqchildren widgets
+ // create children widgets
TQValueVector< KPDFPage * >::const_iterator setIt = pageSet.begin(), setEnd = pageSet.end();
for ( ; setIt != setEnd; ++setIt )
d->items.push_back( new PageViewItem( *setIt ) );
@@ -397,8 +397,8 @@ void PageView::notifyViewportChanged( bool smoothMove )
if ( !KpdfSettings::viewContinuous() || d->dirtyLayout )
slotRelayoutPages();
- // restore viewport center or use default {x-center,v-top} tqalignment
- const TQRect & r = item->tqgeometry();
+ // restore viewport center or use default {x-center,v-top} alignment
+ const TQRect & r = item->geometry();
int newCenterX = r.left(),
newCenterY = r.top();
if ( vp.rePos.enabled )
@@ -462,13 +462,13 @@ void PageView::notifyPageChanged( int pageNumber, int changedFlags )
if ( changedFlags & DocumentObserver::Bookmark )
return;
// iterate over visible items: if page(pageNumber) is one of them, tqrepaint it
TQValueList< PageViewItem * >::iterator iIt = d->visibleItems.begin(), iEnd = d->visibleItems.end();
for ( ; iIt != iEnd; ++iIt )
if ( (*iIt)->pageNumber() == pageNumber )
{
// update item's rectangle plus the little outline
- TQRect expandedRect = (*iIt)->tqgeometry();
+ TQRect expandedRect = (*iIt)->geometry();
expandedRect.addCoords( -1, -1, 3, 3 );
updateContents( expandedRect );
@@ -535,7 +535,7 @@ void PageView::viewportPaintEvent( TQPaintEvent * pe )
d->selectionRectColor : TQt::red;
// subdivide region into rects
- TQMemArray<TQRect> allRects = TQRegion(pe->region()).tqrects();
+ TQMemArray<TQRect> allRects = TQRegion(pe->region()).rects();
uint numRects = allRects.count();
// preprocess rects area to see if it worths or not using subdivision
@@ -662,7 +662,7 @@ void PageView::keyPressEvent( TQKeyEvent * e )
bool found = d->document->searchText( PAGEVIEW_SEARCH_ID, d->typeAheadString, true, false,
KPDFDocument::NextMatch, true, tqRgb( 128, 255, 128 ), true );
TQString status = found ? i18n("Text found: \"%1\".") : i18n("Text not found: \"%1\".");
- d->messageWindow->display( status.tqarg(d->typeAheadString.lower()),
+ d->messageWindow->display( status.arg(d->typeAheadString.lower()),
found ? PageViewMessage::Find : PageViewMessage::Warning, 4000 );
d->findTimeoutTimer->start( 3000, true );
}
@@ -682,7 +682,7 @@ void PageView::keyPressEvent( TQKeyEvent * e )
// because it activates the accel
releaseKeyboard();
if ( d->document->continueSearch( PAGEVIEW_SEARCH_ID ) )
- d->messageWindow->display( i18n("Text found: \"%1\".").tqarg(d->typeAheadString.lower()),
+ d->messageWindow->display( i18n("Text found: \"%1\".").arg(d->typeAheadString.lower()),
PageViewMessage::Find, 3000 );
d->findTimeoutTimer->start( 3000, true );
// it is needed to grab the keyboard becase people may have Space assigned to a
@@ -847,7 +847,7 @@ void PageView::contentsMouseMoveEvent( TQMouseEvent * e )
d->zoomFactor *= ( 1.0 + ( (double)deltaY / 500.0 ) );
updateZoom( ZoomRefreshCurrent );
// uncomment following line to force a complete redraw
- viewport()->tqrepaint( false );
+ viewport()->repaint( false );
return;
}
@@ -1006,8 +1006,8 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
// if the mouse has not moved since the press, that's a -click-
if ( leftButton && pageItem && d->mousePressPos == e->globalPos())
{
- double nX = (double)(e->x() - pageItem->tqgeometry().left()) / (double)pageItem->width(),
- nY = (double)(e->y() - pageItem->tqgeometry().top()) / (double)pageItem->height();
+ double nX = (double)(e->x() - pageItem->geometry().left()) / (double)pageItem->width(),
+ nY = (double)(e->y() - pageItem->geometry().top()) / (double)pageItem->height();
const ObjectRect * linkRect, * imageRect;
linkRect = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
if ( linkRect )
@@ -1105,7 +1105,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
for ( ; iIt != iEnd; ++iIt )
{
PageViewItem * item = *iIt;
- const TQRect & itemRect = item->tqgeometry();
+ const TQRect & itemRect = item->geometry();
if ( selectionRect.intersects( itemRect ) )
{
// request the textpage if there isn't one
@@ -1131,7 +1131,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
if ( KpdfSettings::useKTTSD() )
menu.insertItem( SmallIcon("kttsd"), i18n( "Speak Text" ), 2 );
}
- menu.insertTitle( i18n( "Image (%1 by %2 pixels)" ).tqarg( selectionRect.width() ).tqarg( selectionRect.height() ) );
+ menu.insertTitle( i18n( "Image (%1 by %2 pixels)" ).arg( selectionRect.width() ).arg( selectionRect.height() ) );
menu.insertItem( SmallIcon("image"), i18n( "Copy to Clipboard" ), 3 );
menu.insertItem( SmallIcon("filesave"), i18n( "Save to File..." ), 4 );
int choice = menu.exec( e->globalPos() );
@@ -1151,7 +1151,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
cb->setPixmap( copyPix, TQClipboard::Clipboard );
if ( cb->supportsSelection() )
cb->setPixmap( copyPix, TQClipboard::Selection );
- d->messageWindow->display( i18n( "Image [%1x%2] copied to clipboard." ).tqarg( copyPix.width() ).tqarg( copyPix.height() ) );
+ d->messageWindow->display( i18n( "Image [%1x%2] copied to clipboard." ).arg( copyPix.width() ).arg( copyPix.height() ) );
}
else if ( choice == 4 )
{
@@ -1165,7 +1165,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
if ( type.isNull() )
type = "PNG";
copyPix.save( fileName, type.latin1() );
- d->messageWindow->display( i18n( "Image [%1x%2] saved to %3 file." ).tqarg( copyPix.width() ).tqarg( copyPix.height() ).tqarg( type ) );
+ d->messageWindow->display( i18n( "Image [%1x%2] saved to %3 file." ).arg( copyPix.width() ).arg( copyPix.height() ).arg( type ) );
}
}
}
@@ -1194,7 +1194,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
TQString error;
if (KApplication::startServiceByDesktopName("kttsd", TQStringList(), &error))
{
- d->messageWindow->display( i18n("Starting KTTSD Failed: %1").tqarg(error) );
+ d->messageWindow->display( i18n("Starting KTTSD Failed: %1").arg(error) );
KpdfSettings::setUseKTTSD(false);
KpdfSettings::writeConfig();
}
@@ -1221,7 +1221,7 @@ void PageView::contentsMouseReleaseEvent( TQMouseEvent * e )
}
}
- // clear widget selection and tqinvalidate rect
+ // clear widget selection and invalidate rect
selectionClear();
// restore previous action if came from it using right button
@@ -1323,17 +1323,17 @@ void PageView::paintItems( TQPainter * p, const TQRect & contentsRect )
for ( ; iIt != iEnd; ++iIt )
{
// check if a piece of the page intersects the contents rect
- if ( !(*iIt)->tqgeometry().intersects( checkRect ) )
+ if ( !(*iIt)->geometry().intersects( checkRect ) )
continue;
PageViewItem * item = *iIt;
- TQRect pixmapGeometry = item->tqgeometry();
+ TQRect pixmapGeometry = item->geometry();
// translate the painter so we draw top-left pixmap corner in 0,0
p->save();
p->translate( pixmapGeometry.left(), pixmapGeometry.top() );
- // item pixmap and outline tqgeometry
+ // item pixmap and outline geometry
TQRect outlineGeometry = pixmapGeometry;
outlineGeometry.addCoords( -1, -1, 3, 3 );
@@ -1378,7 +1378,7 @@ void PageView::paintItems( TQPainter * p, const TQRect & contentsRect )
}
// paint with background color the unpainted area
- TQMemArray<TQRect> backRects = remainingArea.tqrects();
+ TQMemArray<TQRect> backRects = remainingArea.rects();
uint backRectsNumber = backRects.count();
for ( uint jr = 0; jr < backRectsNumber; jr++ )
p->fillRect( backRects[ jr ], TQt::gray );
@@ -1424,7 +1424,7 @@ PageViewItem * PageView::pickItemOnPoint( int x, int y )
for ( ; iIt != iEnd; ++iIt )
{
PageViewItem * i = *iIt;
- const TQRect & r = i->tqgeometry();
+ const TQRect & r = i->geometry();
if ( x < r.right() && x > r.left() && y < r.bottom() )
{
if ( y > r.top() )
@@ -1485,7 +1485,7 @@ void PageView::selectionEndPoint( int x, int y )
compoundRegion -= intersection;
}
// tassellate region with rects and enqueue paint events
- TQMemArray<TQRect> rects = compoundRegion.tqrects();
+ TQMemArray<TQRect> rects = compoundRegion.rects();
for ( uint i = 0; i < rects.count(); i++ )
updateContents( rects[i] );
}
@@ -1599,7 +1599,7 @@ void PageView::updateZoomText()
selIdx++;
TQString localValue( KGlobal::locale()->formatNumber( value * 100.0, 2 ) );
localValue.remove( KGlobal::locale()->decimalSymbol() + double_oh );
- translated << TQString( "%1%" ).tqarg( localValue );
+ translated << TQString( "%1%" ).arg( localValue );
}
d->aZoom->setItems( translated );
@@ -1619,8 +1619,8 @@ void PageView::updateCursor( const TQPoint &p )
PageViewItem * pageItem = pickItemOnPoint( p.x(), p.y() );
if ( pageItem && d->mouseMode == MouseNormal )
{
- double nX = (double)(p.x() - pageItem->tqgeometry().left()) / (double)pageItem->width(),
- nY = (double)(p.y() - pageItem->tqgeometry().top()) / (double)pageItem->height();
+ double nX = (double)(p.x() - pageItem->geometry().left()) / (double)pageItem->width(),
+ nY = (double)(p.y() - pageItem->geometry().top()) / (double)pageItem->height();
// if over a ObjectRect (of type Link) change cursor to hand
d->mouseOnRect = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
@@ -1643,7 +1643,7 @@ void PageView::doTypeAheadSearch()
bool found = d->document->searchText( PAGEVIEW_SEARCH_ID, d->typeAheadString, false, false,
KPDFDocument::NextMatch, true, tqRgb( 128, 255, 128 ), true );
TQString status = found ? i18n("Text found: \"%1\".") : i18n("Text not found: \"%1\".");
- d->messageWindow->display( status.tqarg(d->typeAheadString.lower()),
+ d->messageWindow->display( status.arg(d->typeAheadString.lower()),
found ? PageViewMessage::Find : PageViewMessage::Warning, 4000 );
d->findTimeoutTimer->start( 3000, true );
}
@@ -1677,7 +1677,7 @@ void PageView::slotRelayoutPages()
fullHeight = 0;
TQRect viewportRect( contentsX(), contentsY(), viewportWidth, viewportHeight );
- // set all items tqgeometry and resize contents. handle 'continuous' and 'single' modes separately
+ // set all items geometry and resize contents. handle 'continuous' and 'single' modes separately
if ( KpdfSettings::viewContinuous() )
{
// Here we find out column's width and row's height to compute a table
@@ -1816,11 +1816,11 @@ void PageView::slotRelayoutPages()
{
int prevX = contentsX(),
prevY = contentsY();
- const TQRect & tqgeometry = d->items[ vp.pageNumber ]->tqgeometry();
+ const TQRect & geometry = d->items[ vp.pageNumber ]->geometry();
double nX = vp.rePos.enabled ? vp.rePos.normalizedX : 0.5,
nY = vp.rePos.enabled ? vp.rePos.normalizedY : 0.0;
- center( tqgeometry.left() + ROUND( nX * (double)tqgeometry.width() ),
- tqgeometry.top() + ROUND( nY * (double)tqgeometry.height() ) );
+ center( geometry.left() + ROUND( nX * (double)geometry.width() ),
+ geometry.top() + ROUND( nY * (double)geometry.height() ) );
// center() usually moves the viewport, that requests pixmaps too.
// if that doesn't happen we have to request them by hand
if ( prevX == contentsX() && prevY == contentsY() )
@@ -1867,7 +1867,7 @@ void PageView::slotRequestVisiblePixmaps( int newLeft, int newTop )
PageViewItem * i = *iIt;
// if the item doesn't intersect the viewport, skip it
- if ( !viewportRect.intersects( i->tqgeometry() ) )
+ if ( !viewportRect.intersects( i->geometry() ) )
continue;
// add the item to the 'visible list'
@@ -1885,18 +1885,18 @@ void PageView::slotRequestVisiblePixmaps( int newLeft, int newTop )
// position between the item and the viewport center
if ( isEvent )
{
- const TQRect & tqgeometry = i->tqgeometry();
+ const TQRect & geometry = i->geometry();
// compute distance between item center and viewport center
- double distance = hypot( (tqgeometry.left() + tqgeometry.right()) / 2 - viewportCenterX,
- (tqgeometry.top() + tqgeometry.bottom()) / 2 - viewportCenterY );
+ double distance = hypot( (geometry.left() + geometry.right()) / 2 - viewportCenterX,
+ (geometry.top() + geometry.bottom()) / 2 - viewportCenterY );
if ( distance >= minDistance && nearPageNumber != -1 )
continue;
nearPageNumber = i->pageNumber();
minDistance = distance;
- if ( tqgeometry.height() > 0 && tqgeometry.width() > 0 )
+ if ( geometry.height() > 0 && geometry.width() > 0 )
{
- focusedX = ( viewportCenterX - (double)tqgeometry.left() ) / (double)tqgeometry.width();
- focusedY = ( viewportCenterY - (double)tqgeometry.top() ) / (double)tqgeometry.height();
+ focusedX = ( viewportCenterX - (double)geometry.left() ) / (double)geometry.width();
+ focusedY = ( viewportCenterY - (double)geometry.top() ) / (double)geometry.height();
}
}
}
@@ -462,13 +462,13 @@ void PageView::notifyPageChanged( int pageNumber, int changedFlags )
if ( changedFlags & DocumentObserver::Bookmark )
return;
- // iterate over visible items: if page(pageNumber) is one of them, tqrepaint it
+ // iterate over visible items: if page(pageNumber) is one of them, repaint it
TQValueList< PageViewItem * >::iterator iIt = d->visibleItems.begin(), iEnd = d->visibleItems.end();
for ( ; iIt != iEnd; ++iIt )
diff --git a/kpdf/ui/pageviewutils.cpp b/kpdf/ui/pageviewutils.cpp
index a948d49c..27565753 100644
--- a/kpdf/ui/pageviewutils.cpp
+++ b/kpdf/ui/pageviewutils.cpp
@@ -54,7 +54,7 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
iconXOffset = 0,
shadowOffset = 1;
// load icon (if set) and update tqgeometry
TQPixmap symbol;
if ( icon != None )
{
@@ -84,33 +84,33 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
width += 2 + symbol.width();
height = TQMAX( height, symbol.height() );
}
- TQRect tqgeometry( 0, 0, width + 10, height + 8 );
+ TQRect geometry( 0, 0, width + 10, height + 8 );
// resize pixmap, mask and widget
static TQBitmap mask;
- mask.resize( tqgeometry.size() );
- m_pixmap.resize( tqgeometry.size() );
- resize( tqgeometry.size() );
+ mask.resize( geometry.size() );
+ m_pixmap.resize( geometry.size() );
+ resize( geometry.size() );
// create and set transparency mask
TQPainter maskPainter( &mask);
mask.fill( TQt::black );
maskPainter.setBrush( TQt::white );
- maskPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
+ maskPainter.drawRoundRect( geometry, 1600 / geometry.width(), 1600 / geometry.height() );
setMask( mask );
// draw background
TQPainter bufferPainter( &m_pixmap );
bufferPainter.setPen( TQt::black );
bufferPainter.setBrush( paletteBackgroundColor() );
- bufferPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
+ bufferPainter.drawRoundRect( geometry, 1600 / geometry.width(), 1600 / geometry.height() );
// draw icon if present
if ( !symbol.isNull() )
bufferPainter.drawPixmap( 5 + iconXOffset, 4, symbol, 0, 0, symbol.width(), symbol.height() );
// draw shadow and text
- int yText = tqgeometry.height() - height / 2;
+ int yText = geometry.height() - height / 2;
bufferPainter.setPen( paletteBackgroundColor().dark( 115 ) );
bufferPainter.drawText( 5 + textXOffset + shadowOffset, yText + 1, message );
bufferPainter.setPen( foregroundColor() );
@@ -119,9 +119,9 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
// if the tqlayout is RtL, we can move it to the right place only after we
// know how much size it will take
if ( TQApplication::reverseLayout() )
- move( parentWidget()->width() - tqgeometry.width() - 10, 10 );
+ move( parentWidget()->width() - geometry.width() - 10, 10 );
- // show widget and schedule a tqrepaint
+ // show widget and schedule a repaint
show();
update();
@@ -168,19 +168,19 @@ int PageViewItem::pageNumber() const
return m_page->number();
}
-const TQRect& PageViewItem::tqgeometry() const
+const TQRect& PageViewItem::geometry() const
{
- return m_tqgeometry;
+ return m_geometry;
}
int PageViewItem::width() const
{
- return m_tqgeometry.width();
+ return m_geometry.width();
}
int PageViewItem::height() const
{
- return m_tqgeometry.height();
+ return m_geometry.height();
}
double PageViewItem::zoomFactor() const
@@ -190,18 +190,18 @@ double PageViewItem::zoomFactor() const
void PageViewItem::setGeometry( int x, int y, int width, int height )
{
- m_tqgeometry.setRect( x, y, width, height );
+ m_geometry.setRect( x, y, width, height );
}
void PageViewItem::setWHZ( int w, int h, double z )
{
- m_tqgeometry.setWidth( w );
- m_tqgeometry.setHeight( h );
+ m_geometry.setWidth( w );
+ m_geometry.setHeight( h );
m_zoomFactor = z;
}
void PageViewItem::moveTo( int x, int y )
{
- m_tqgeometry.moveLeft( x );
- m_tqgeometry.moveTop( y );
+ m_geometry.moveLeft( x );
+ m_geometry.moveTop( y );
}
@@ -54,7 +54,7 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
iconXOffset = 0,
shadowOffset = 1;
- // load icon (if set) and update tqgeometry
+ // load icon (if set) and update geometry
TQPixmap symbol;
if ( icon != None )
diff --git a/kpdf/ui/pageviewutils.h b/kpdf/ui/pageviewutils.h
index ceac9fe2..68c2f08b 100644
--- a/kpdf/ui/pageviewutils.h
+++ b/kpdf/ui/pageviewutils.h
@@ -23,7 +23,7 @@ class KPDFPage;
/**
* @short PageViewItem represents graphically a kpdfpage into the PageView.
*
* It has methods for settings Item's tqgeometry and other visual properties such
* as the individual zoom factor.
*/
class PageViewItem
@@ -33,7 +33,7 @@ class PageViewItem
const KPDFPage * page() const;
int pageNumber() const;
- const TQRect& tqgeometry() const;
+ const TQRect& geometry() const;
int width() const;
int height() const;
double zoomFactor() const;
@@ -45,7 +45,7 @@ class PageViewItem
private:
const KPDFPage * m_page;
double m_zoomFactor;
- TQRect m_tqgeometry;
+ TQRect m_geometry;
};
@@ -23,7 +23,7 @@ class KPDFPage;
* @short PageViewItem represents graphically a kpdfpage into the PageView.
*
- * It has methods for settings Item's tqgeometry and other visual properties such
+ * It has methods for settings Item's geometry and other visual properties such
* as the individual zoom factor.
*/